//  Copyright Snap Inc. All rights reserved.
//  CameraKit

#import "SCCameraKitInput.h"

@class ARSession;
@class ARAnchor;
@protocol ARSessionDelegate;

NS_ASSUME_NONNULL_BEGIN

@protocol SCCameraKitARInput;

NS_SWIFT_NAME(ARInputDelegate)
/// Propogates ARKit session delegate methods back to CameraKit.
/// If you implement your own AR Input, you _MUST_ call these methods when their corresponding ARKit delegate methods are called.
@protocol SCCameraKitARInputDelegate

/// Method to call when the input receives session:didAddAnchors:
/// @param input the sending input
/// @param anchors the anchors passed to the delegate
- (void)input:(id<SCCameraKitARInput>)input didAddAnchors:(NSArray<ARAnchor *> *)anchors;

/// Method to call when the input receives session:didUpdateAnchors:
/// @param input the sending input
/// @param anchors the anchors passed to the delegate
- (void)input:(id<SCCameraKitARInput>)input didUpdateAnchors:(NSArray<ARAnchor *> *)anchors;

/// Method to call when the input receives session:didRemoveAnchors:
/// @param input the sending input
/// @param anchors the anchors passed to the delegate
- (void)input:(id<SCCameraKitARInput>)input didRemoveAnchors:(NSArray<ARAnchor *> *)anchors;

@end

NS_SWIFT_NAME(ARInput)

/// Describes a source of AR data for CameraKit.
@protocol SCCameraKitARInput <SCCameraKitInput>

/// The managed ARSession.
@property (nonatomic, strong, readonly) ARSession *session;

/// The intermediate destination for ARKit delegate methods. See the protocol definition for more details.
/// This property should _NOT_ be set directly. CameraKit will assign this as appropriate.
@property (nonatomic, weak) id<SCCameraKitARInputDelegate> arDelegate;

@end

NS_ASSUME_NONNULL_END
