//  Copyright Snap Inc. All rights reserved.
//  CameraKit

#import <Foundation/Foundation.h>

@protocol SCCameraKitDeviceMotionDataProvider;
@protocol SCCameraKitUserDataProvider;

NS_ASSUME_NONNULL_BEGIN

NS_SWIFT_NAME(DataProviderComponent)
/// Component for user's custom data providers
@interface SCCameraKitDataProviderComponent : NSObject

/// Device motion data provider
@property (nonatomic, strong, readonly, nullable) id<SCCameraKitDeviceMotionDataProvider> deviceMotion;

/// User data provider
@property (nonatomic, strong, readonly, nullable) id<SCCameraKitUserDataProvider> userData;

/// Designated init to pass in user data providers
/// If nil is passed in for a specific data provider, CameraKit will create and handle the data provider by default
/// @param deviceMotion device motion data provider instance
/// @param userData user data provider instance
- (instancetype)initWithDeviceMotion:(nullable id<SCCameraKitDeviceMotionDataProvider>)deviceMotion
                            userData:(nullable id<SCCameraKitUserDataProvider>)userData NS_DESIGNATED_INITIALIZER;

@end

NS_ASSUME_NONNULL_END
