//  Copyright Snap Inc. All rights reserved.
//  CameraKit

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

NS_SWIFT_NAME(LensPreview)
/// Describes an interface that contains lens preview data
@protocol SCCameraKitLensPreview <NSObject>

/// URL for image preview
@property (copy, nonatomic, readonly, nullable) NSURL *imageUrl;

@end

NS_SWIFT_NAME(Lens)
/// Describes a lens object.
@protocol SCCameraKitLens <NSObject>

/// A unique identifier for the lens.
@property (copy, nonatomic, readonly) NSString *identifier NS_SWIFT_NAME(id);

/// A unique identifier for the group that the lens belongs to
@property (copy, nonatomic, readonly) NSString *groupIdentifier NS_SWIFT_NAME(groupId);

/// The name for the lens
@property (copy, nonatomic, readonly, nullable) NSString *name;

/// URL for icon image
@property (copy, nonatomic, readonly, nullable) NSURL *iconUrl;

/// Lens preview instance
@property (strong, nonatomic, readonly) id<SCCameraKitLensPreview> preview;

/// Extra metadata provided from vendor
@property (copy, nonatomic, readonly) NSDictionary<NSString *, NSString *> *vendorData;

@end

NS_ASSUME_NONNULL_END
