//  Copyright Snap Inc. All rights reserved.
//  CameraKit

#import <Foundation/Foundation.h>

@protocol SCCameraKitLens;

NS_ASSUME_NONNULL_BEGIN

NS_SWIFT_NAME(LensPrefetcherTask)
/// Describes the interface used to cancel an ongoing prefetch task
@protocol SCCameraKitLensPrefetcherTask <NSObject>

/// Cancel prefetch task if it's ongoing
- (void)cancel;

@end

NS_SWIFT_NAME(LensPrefetcher)
/// Describes the interface used to prefetch lens content
@protocol SCCameraKitLensPrefetcher <NSObject>

/// Queues up a new fetch task for each of the `lenses` in order to prefetch their content.
/// A successful callback indiciates that all the content for the list of `lenses` is ready to be used/applied in lens processor
/// @param lenses lenses to prefetch content for
/// @param completion callback on completion with success or failure
- (id<SCCameraKitLensPrefetcherTask>)prefetchLenses:(NSArray<id<SCCameraKitLens>> *)lenses
                                         completion:(nullable void (^)(BOOL success))completion NS_SWIFT_NAME(prefetch(lens:completion:));

@end

NS_ASSUME_NONNULL_END
