//  Copyright Snap Inc. All rights reserved.
//  CameraKit

#import <UIKit/UIKit.h>
#import <AVFoundation/AVFoundation.h>
#import "SCCameraKitOutput.h"
#import "SCCameraKitOutputRequiringPixelBuffer.h"

NS_ASSUME_NONNULL_BEGIN

NS_SWIFT_NAME(PhotoCaptureOutput)
/// An output that will capture photos. You should add this as an output for your CameraKit instance.
@interface SCCameraKitPhotoCaptureOutput : NSObject <SCCameraKitOutput, SCCameraKitOutputRequiringPixelBuffer>

- (instancetype)init NS_UNAVAILABLE;
+ (instancetype)new NS_UNAVAILABLE;

/// Instantiates a capturer with the specified AVCapturePhotoOutput and capture settings.
/// @param output the photo output to be used if possible. May be nil (in which case a frame from the video stream will be captured).
/// @note the AVCapturePhotoOutput will be used when possible, but this is not guarunteed in all scenarios (such as when an ARKit lens is active)
- (instancetype)initWithCapturePhotoOutput:(nullable AVCapturePhotoOutput *)output;

/// Capture a photo and call a completion with the resulting image when done.
/// @param settings the photo capture settings to be used. If nil, the default settings will be used.
/// @param completion the completion block called with the captured image.
- (void)capturePhotoWithCaptureSettings:(nullable AVCapturePhotoSettings *)settings completion:(void (^)(UIImage * _Nullable image, NSError * _Nullable error))completion NS_SWIFT_NAME(capture(with:completion:));

NS_ASSUME_NONNULL_END

@end

