import GRPC
import Logging
import NIO
import NIOHTTP1
import SwiftProtobuf
import XCTest

@testable import Networking

final class GRPCTests: XCTestCase {

    var manager: NetworkCore.GRPCManager!
    var token: String!
    var url: URL!
    var factory: FakeStreamFactory!

    override func setUp() {
        token = "eyJhbGciOiJIUzI1NiIsImlhdCI6MTU5ODk0NjkwMCwiZXhwIjoxNjUwNzg2OTAwfQ."
            + "eyJpZCI6IjE3NTQzMzcifQ.9rPPcuB8BsF2MtcpEajY3k5y14yLo--UvIDWr76NH5Q"
        url = URL(string: "https://reco-signal-api.dev.triller.co:50051")
        factory = FakeStreamFactory()
        manager = NetworkCore.GRPCManager(url: url,
                                          authToken: token,
                                          worker: NetworkCore.eventLoopGroup,
                                          streamFactory: factory)
    }

    func test_update_usesNewAuthToken() {
        let newToken = "fake_token.fake_token"
        manager.update(url: url, authToken: newToken)
        XCTAssertEqual(factory.authToken, newToken)
    }

    func test_update_createsNewStream() {
        let exp = expectation(description: "update stream")
        manager.update(url: url, authToken: token) {
            XCTAssertNotNil(self.factory.request)
            exp.fulfill()
        }
        wait(for: [exp], timeout: 2.0)
    }
}
