import GRPC
import NIO
import NIOHPACK
import XCTest
@testable import Networking

class StreamMockTests: XCTestCase {
    private typealias Request = TrillerSignalsSignalRequest
    private typealias Response = TrillerSignalsStatus

    func testStreamingSendMessage() {
        let stream = FakeStreamingResponse<Request, Response>()
        do {
            try  stream.sendMessage(.with({ (response) in
                XCTAssertTrue(response.code == 0)
            }))
        } catch {
            XCTFail("Failed to send stream \(error)")
        }
    }

    func testStreamingSendInitialMetadata() {
        let stream = FakeStreamingResponse<Request, Response>()
        XCTAssertNoThrow(try stream.sendInitialMetadata(["Authorization": "kfdhiwjdisds"]))
        // This should be dropped.
        XCTAssertThrowsError(try stream.sendInitialMetadata(["Authorization": "kfdhiwjdisds"])) { error in
            XCTAssertTrue(error is FakeResponseProtocolViolation)
        }
        // Trailers and status.
        XCTAssertNoThrow(try stream.sendEnd(trailingMetadata: ["Authorization": "kfdhiwjdisds"]))
    }

    func testStreamingSendError() {
        let stream = FakeStreamingResponse<Request, Response>()
        XCTAssertNoThrow(try stream.sendMessage(.with { $0.code = 0 }))
        XCTAssertNoThrow(try stream.sendError(GRPCError.RPCCancelledByClient()))
    }
}
